@@ -357,12 +357,20 @@ ETHEREUM_RINKEBY_NETWORK_NAME: str = "Rinkeby"
 ETHEREUM_MAINNET_NETWORK_NUM: int = 5
 ETHEREUM_BSC_MAINNET_NETWORK_NUM: int = 10
 ETHEREUM_POLYGON_MAINNET_NETWORK_NUM: int = 36
+ETHEREUM_SOLANA_MAINNET_NETWORK_NUM: int = 41
+ETHEREUM_KILN_MAINNET_NETWORK_NUM: int = 42
 ETHEREUM_RINKEBY_NETWORK_NUM: int = 29
 
 BLOCKCHAIN_NETWORK_NUM_TO_NETWORK_NAME = {
     ETHEREUM_MAINNET_NETWORK_NUM: "Ethereum",
     ETHEREUM_BSC_MAINNET_NETWORK_NUM: "BSC",
-    ETHEREUM_POLYGON_MAINNET_NETWORK_NUM: "Polygon"
+    ETHEREUM_POLYGON_MAINNET_NETWORK_NUM: "Polygon",
+    ETHEREUM_SOLANA_MAINNET_NETWORK_NUM: "Solana",
+    ETHEREUM_KILN_MAINNET_NETWORK_NUM: "Kiln",
 }
 
 ALLOWED_NETWORKS = {"Mainnet": 5}
+
+ZERO_NODES: int = 0
+ONE_NODE: int = 1
+MULTIPLE_NODES: int = 2
