@@ -1,5 +1,6 @@
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
 from bxcommon.messages.bloxroute.v20.tx_message_converter_v20 import tx_message_converter_v20
+from bxcommon.messages.bloxroute.v21.message_converter_factory_v21 import message_converter_factory_v21
 from bxcommon.messages.versioning.abstract_version_converter_factory import AbstractMessageConverterFactory
 from bxcommon.messages.versioning.no_changes_message_converter import no_changes_message_converter
 
@@ -7,6 +8,7 @@ from bxcommon.messages.versioning.no_changes_message_converter import no_changes
 class _MessageConverterFactoryV20(AbstractMessageConverterFactory):
     _MESSAGE_CONVERTER_MAPPING = {
         # pylint: disable=protected-access
+        **message_converter_factory_v21._MESSAGE_CONVERTER_MAPPING,
         BloxrouteMessageType.TRANSACTION: tx_message_converter_v20,
     }
 
