@@ -6,5 +6,5 @@ class SerializeableEnum(Enum):
     def __hash__(self):
         return hash(self.value)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self.value)
