@@ -39,3 +39,5 @@ class RpcRequestType(SerializeableEnum):
     ADD_MEV_CREDIT = 34
     GET_MEV_CREDIT = 35
     ETH_SUBSCRIBE = 36
+    PRIVATE_TX_BALANCE = 37
+    BLXR_SUBMIT_MEGA_BUNDLE = 38
