@@ -1,10 +1,10 @@
 import sys
 
 P2P_PROTOCOL_VERSION = 4
-ETH_PROTOCOL_VERSION = 65
-SUPPORTED_ETH_PROTOCOL_VERSION = [ETH_PROTOCOL_VERSION, 64, 63]
+ETH_PROTOCOL_VERSION = 66
+SUPPORTED_ETH_PROTOCOL_VERSION = [ETH_PROTOCOL_VERSION, 65, 64, 63]
 CAPABILITIES = ((b"eth", ETH_PROTOCOL_VERSION),)
-BX_ETH_CLIENT_NAME = b"BloxRoute Gateway"
+BX_ETH_CLIENT_NAME = b"bloXroute Gateway"
 
 SIGNATURE_LEN = 65
 MDC_LEN = 32
