@@ -10,31 +10,32 @@ NODE_TO_CONNECTION_TYPE: Dict[NodeType, Dict[NodeType, ConnectionType]] = {
         NodeType.GATEWAY: ConnectionType.GATEWAY,
         NodeType.INTERNAL_GATEWAY: ConnectionType.GATEWAY,
         NodeType.EXTERNAL_GATEWAY: ConnectionType.GATEWAY,
-        NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_TRANSACTION,
-        NodeType.RELAY_BLOCK: ConnectionType.RELAY_BLOCK,
+        NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_ALL,
+        NodeType.RELAY_BLOCK: ConnectionType.RELAY_ALL,
         NodeType.RELAY: ConnectionType.RELAY_ALL
     },
     NodeType.INTERNAL_GATEWAY: {
         NodeType.GATEWAY: ConnectionType.GATEWAY,
         NodeType.INTERNAL_GATEWAY: ConnectionType.INTERNAL_GATEWAY,
         NodeType.EXTERNAL_GATEWAY: ConnectionType.EXTERNAL_GATEWAY,
-        NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_TRANSACTION,
-        NodeType.RELAY_BLOCK: ConnectionType.RELAY_BLOCK,
-        NodeType.RELAY: ConnectionType.RELAY_ALL
+        NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_ALL,
+        NodeType.RELAY_BLOCK: ConnectionType.RELAY_ALL,
+        NodeType.RELAY: ConnectionType.RELAY_ALL,
+        NodeType.RELAY_PROXY: ConnectionType.RELAY_ALL,
     },
     NodeType.EXTERNAL_GATEWAY: {
         NodeType.GATEWAY: ConnectionType.GATEWAY,
         NodeType.INTERNAL_GATEWAY: ConnectionType.INTERNAL_GATEWAY,
         NodeType.EXTERNAL_GATEWAY: ConnectionType.EXTERNAL_GATEWAY,
-        NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_TRANSACTION,
-        NodeType.RELAY_BLOCK: ConnectionType.RELAY_BLOCK,
-        NodeType.RELAY: ConnectionType.RELAY_ALL
+        NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_ALL,
+        NodeType.RELAY_BLOCK: ConnectionType.RELAY_ALL,
+        NodeType.RELAY: ConnectionType.RELAY_ALL,
+        NodeType.RELAY_PROXY: ConnectionType.RELAY_ALL,
     },
     NodeType.RELAY_BLOCK: {
         NodeType.GATEWAY: ConnectionType.GATEWAY,
         NodeType.INTERNAL_GATEWAY: ConnectionType.INTERNAL_GATEWAY,
         NodeType.EXTERNAL_GATEWAY: ConnectionType.EXTERNAL_GATEWAY,
-        NodeType.RELAY_TRANSACTION: ConnectionType.CROSS_RELAY,
         NodeType.RELAY_BLOCK: ConnectionType.RELAY_BLOCK,
         NodeType.RELAY_PROXY: ConnectionType.RELAY_PROXY,
         NodeType.RELAY: ConnectionType.RELAY_ALL,
@@ -46,7 +47,6 @@ NODE_TO_CONNECTION_TYPE: Dict[NodeType, Dict[NodeType, ConnectionType]] = {
         NodeType.EXTERNAL_GATEWAY: ConnectionType.EXTERNAL_GATEWAY,
         NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_TRANSACTION,
         NodeType.RELAY_PROXY: ConnectionType.RELAY_PROXY,
-        NodeType.RELAY_BLOCK: ConnectionType.CROSS_RELAY,
         NodeType.RELAY: ConnectionType.RELAY_ALL,
         NodeType.API_SOCKET: ConnectionType.SDN
     },
