@@ -751,7 +751,8 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
                                                  peer_info.endpoint.ip_address,
                                                  peer_info.endpoint.port,
                                                  "Connection refused")
-        elif peer_info.connection_type == ConnectionType.EXTERNAL_GATEWAY:
+        elif peer_info.connection_type == ConnectionType.EXTERNAL_GATEWAY or \
+            peer_info.connection_type == ConnectionType.REMOTE_BLOCKCHAIN_NODE:
             logger.debug("Failed to connect to: {}, {}.", peer_info, error)
         else:
             super(AbstractGatewayNode, self).log_refused_connection(peer_info, error)
