@@ -1,5 +1,5 @@
+from bxcommon.feed.raw_block import AbstractRawBlock
 from bxgateway.messages.eth.internal_eth_block_info import InternalEthBlockInfo
-from bxgateway.feed.raw_block import AbstractRawBlock
 
 
 class EthRawBlock(AbstractRawBlock[InternalEthBlockInfo]):
