@@ -31,14 +31,14 @@ class GetBlockHeadersEthProtocolMessage(EthProtocolMessage):
 
     def get_block_hash(self) -> Optional[Sha256Hash]:
         block_hash_bytes = self.get_field_value("block_hash")
-        if len(block_hash_bytes) != eth_common_constants.BLOCK_HASH_LEN:
+        if block_hash_bytes is None or len(block_hash_bytes) != eth_common_constants.BLOCK_HASH_LEN:
             return None
         else:
             return Sha256Hash(block_hash_bytes)
 
     def get_block_number(self) -> Optional[int]:
         block_hash_bytes = self.get_field_value("block_hash")
-        if len(block_hash_bytes) == eth_common_constants.BLOCK_HASH_LEN:
+        if block_hash_bytes is None or len(block_hash_bytes) == eth_common_constants.BLOCK_HASH_LEN:
             return None
         else:
             return int.from_bytes(block_hash_bytes, byteorder="big")
