@@ -12,7 +12,7 @@ class ReceiptsV66EthProtocolMessage(ReceiptsEthProtocolMessage):
 
     def __repr__(self):
         return (
-            f"{repr(self.get_message())}<request_id: {self.get_request_id()}>"
+            f"<ReceiptsEthProtocolMessage request_id: {self.get_request_id()}>"
         )
 
     def get_request_id(self) -> int:
