@@ -1,4 +1,4 @@
-import rlp
+import blxr_rlp as rlp
 
 from bxgateway.messages.eth.protocol.eth_protocol_message import EthProtocolMessage
 from bxgateway.messages.eth.protocol.eth_protocol_message_type import EthProtocolMessageType
@@ -11,8 +11,9 @@ class StatusEthProtocolMessage(EthProtocolMessage):
               ("network_id", rlp.sedes.big_endian_int),
               ("chain_difficulty", rlp.sedes.big_endian_int),
               ("chain_head_hash", rlp.sedes.binary),
-              ("genesis_hash", rlp.sedes.binary)]
-    
+              ("genesis_hash", rlp.sedes.binary),
+              ("fork_id", rlp.sedes.List([rlp.sedes.binary, rlp.sedes.big_endian_int], strict=False))]
+
     def get_eth_version(self):
         return self.get_field_value("eth_version")
 
@@ -27,3 +28,6 @@ class StatusEthProtocolMessage(EthProtocolMessage):
 
     def get_genesis_hash(self):
         return self.get_field_value("genesis_hash")
+
+    def get_fork_id(self):
+        return self.get_field_value("fork_id")
