@@ -185,7 +185,7 @@ class EthWsProxyPublisher(EthWsSubscriber):
             logger.debug(log_messages.TRANSACTION_NOT_FOUND_IN_MEMPOOL, transaction_key.transaction_hash)
             transaction_feed_stats_service.log_pending_transaction_missing_contents()
         else:
-            if parsed_tx["type"] == "0x2":
+            if parsed_tx.get("type", "0x0") == "0x2":
                 gas_price = int(parsed_tx["maxFeePerGas"], 16)
             else:
                 gas_price = int(parsed_tx["gasPrice"], 16)
